export { isCancel } from '@clack/core'
declare type State,
  TextPrompt,
} from '@clack/core'
declare const unicode: (...args: any[]) => unknown;
declare const S_BAR_START: unknown;
declare const S_RADIO_ACTIVE: unknown;
declare const S_BAR_H: unknown;
declare function symbol(state: State): void;
declare interface LimitOptionsParams<TOption> {
  options: TOption[]
  maxItems: number | undefined
  cursor: number
  style: (option: TOption, active: boolean) => string
}
declare function limitOptions<TOption>(params: LimitOptionsParams<TOption>): string[];
export declare function text(opts: TextOptions): void;
export declare interface PasswordOptions {
  message: string
  mask?: string
  validate?: (value: string) => string | void
}
export declare function password(opts: PasswordOptions): void;
export declare interface ConfirmOptions {
  message: string
  active?: string
  inactive?: string
  initialValue?: boolean
}
export declare function confirm(opts: ConfirmOptions): void;
declare type Primitive = Readonly<string | boolean | number>

type Option<Value> = Value extends Primitive
  ? { value: Value, label?: string, hint?: string }
export declare interface SelectOptions<Value> {
  message: string
  options: Option<Value>[]
  initialValue?: Value
  maxItems?: number
}
export declare function select<Value>(opts: SelectOptions<Value>): void;
export declare function selectKey<Value extends string>(opts: SelectOptions<Value>): void;
export declare interface MultiSelectOptions<Value> {
  message: string
  options: Option<Value>[]
  initialValues?: Value[]
  maxItems?: number
  required?: boolean
  cursorAt?: Value
}
export declare function multiselect<Value>(opts: MultiSelectOptions<Value>): void;
export declare interface GroupMultiSelectOptions<Value> {
  message: string
  options: Record<string, Option<Value>[]>
  initialValues?: Value[]
  required?: boolean
  cursorAt?: Value
}
export declare function groupMultiselect<Value>(opts: GroupMultiSelectOptions<Value>): void;
declare const strip: (str: string) => unknown;
export declare function cancel(message = ''): void;
export declare function intro(title = ''): void;
export declare function outro(message = ''): void;
declare interface Spinner {
  start: (msg: string) => void
  stop: (msg: string, code: number) => void
  message: (msg: string) => void
}
export declare function spinner(): Spinner;
declare function ansiRegex(): void;
export declare type PromptGroupAwaitedReturn<T> = {
  [P in keyof T]: Exclude<Awaited<T[P]>, symbol>
}
export declare interface PromptGroupOptions<T> {
  onCancel?: (opts: { results: Prettify<Partial<PromptGroupAwaitedReturn<T>>> }) => void
}
declare type Prettify<T> = {
  [P in keyof T]: T[P]
} & {}
export declare type PromptGroup<T> = {
  [P in keyof T]: (opts: {
    results: Prettify<Partial<PromptGroupAwaitedReturn<Omit<T, P>>>>
  }) => void | Promise<T[P] | void>
}
export declare function group<T>(prompts: PromptGroup<T>, opts?: PromptGroupOptions<T>): Promise<Prettify<PromptGroupAwaitedReturn<T>>>;
export declare interface Task {
  title: string
  task: (message: (string: string) => void) => string | Promise<string> | void | Promise<void>

  enabled?: boolean
}
export declare function tasks(tasks: Task[]): Promise<void>;